package com.chelvc.framework.common.model;

import java.io.Serializable;

import com.chelvc.framework.common.util.StringUtils;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.NoArgsConstructor;

/**
 * 数字范围对象
 *
 * @author Woody
 * @date 2024/10/30
 */
@Getter
@Builder
@EqualsAndHashCode
@NoArgsConstructor
@AllArgsConstructor
public final class Range implements Serializable {
    /**
     * 最小值
     */
    private Integer min;

    /**
     * 最大值
     */
    private Integer max;

    /**
     * 将字符串转换成数字范围信息
     * <p>
     * 字符串以","号作为最小/大范围的分隔符，如果没有分隔符则默认匹配最小值
     * <p>
     * 示例：(1, 10)、(, 10)、(1, )
     *
     * @param text 范围信息字符串格式
     * @return 范围信息实例
     */
    public static Range parse(String text) {
        return StringUtils.decompose(text, Range::new, Integer::parseInt);
    }

    @Override
    public String toString() {
        StringBuilder buffer = new StringBuilder();
        if (StringUtils.notEmpty(this.min)) {
            buffer.append(this.min);
        }
        buffer.append('\t');
        if (StringUtils.notEmpty(this.max)) {
            buffer.append(this.max);
        }
        return buffer.toString();
    }
}
