package com.chelvc.framework.group;

import java.util.Collection;
import java.util.Map;

/**
 * 分组缓存接口
 *
 * @author Woody
 * @date 2024/9/8
 */
public interface GroupCache {
    /**
     * 获取分组
     *
     * @param key   分组标识
     * @param scene 分组场景
     * @return 分组数字
     */
    int getGroup(Object key, String scene);

    /**
     * 批量获取分组
     *
     * @param key    分组标识
     * @param scenes 分组场景集合
     * @return 分组场景/数字映射表
     */
    Map<String, Integer> getGroups(Object key, Collection<String> scenes);

    /**
     * 设置分组
     *
     * @param key   分组标识
     * @param scene 分组场景
     * @param group 分组数字
     */
    void setGroup(Object key, String scene, int group);

    /**
     * 批量设置分组
     *
     * @param key    分组标识
     * @param groups 分组场景/数字映射表
     */
    void setGroups(Object key, Map<String, Integer> groups);

    /**
     * 初始化分组，当分组场景已存在分组时返回已经存在分组，否则返回当前设置分组
     *
     * @param key   分组标识
     * @param scene 分组场景
     * @param group 分组数字
     * @return 分组数字
     */
    int initializeGroup(Object key, String scene, int group);

    /**
     * 批量初始化分组，当分组场景已存在分组时返回已经存在分组，否则返回当前设置分组
     *
     * @param key    分组标识
     * @param groups 分组场景/数字映射表
     * @return 分组场景/数字映射表
     */
    Map<String, Integer> initializeGroups(Object key, Map<String, Integer> groups);

    /**
     * 移除分组
     *
     * @param key   分组标识
     * @param scene 分组场景
     */
    void removeGroup(Object key, String scene);

    /**
     * 移除分组
     *
     * @param key    分组标识
     * @param scenes 分组场景集合
     */
    void removeGroups(Object key, Collection<String> scenes);
}
