package com.chelvc.framework.rocketmq.fallback;

import com.chelvc.framework.kafka.context.KafkaContextHolder;
import com.chelvc.framework.rocketmq.config.RocketMQProperties;
import com.chelvc.framework.rocketmq.producer.RocketMQProducerWrapper;
import lombok.RequiredArgsConstructor;
import org.apache.rocketmq.client.apis.producer.Producer;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnExpression;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.kafka.annotation.KafkaListenerAnnotationBeanPostProcessor;
import org.springframework.kafka.config.KafkaListenerConfigUtils;
import org.springframework.kafka.config.KafkaListenerEndpointRegistry;

/**
 * RocketMQ降级Kafka配置
 *
 * @author Woody
 * @date 2024/7/13
 */
@Configuration
@ConditionalOnClass(KafkaContextHolder.class)
@ConditionalOnExpression("'${rocketmq.fallbacks}'.contains('KAFKA')")
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class RocketMQKafkaConfigurer {
    private final RocketMQProperties properties;

    @Bean
    public RocketMQProducerWrapper kafkaProducerWrapper() {
        return new RocketMQProducerWrapper() {
            private final int order = properties.getFallbacks().indexOf(RocketMQFallback.KAFKA);

            @Override
            public int getOrder() {
                return this.order;
            }

            @Override
            public Producer wrap(Producer producer) {
                return new RocketMQKafkaProducer(producer);
            }
        };
    }

    @Bean(KafkaListenerConfigUtils.KAFKA_LISTENER_ENDPOINT_REGISTRY_BEAN_NAME)
    public KafkaListenerEndpointRegistry kafkaListenerEndpointRegistry() {
        return new KafkaListenerEndpointRegistry();
    }

    @Bean(KafkaListenerConfigUtils.KAFKA_LISTENER_ANNOTATION_PROCESSOR_BEAN_NAME)
    public KafkaListenerAnnotationBeanPostProcessor<?, ?> kafkaListenerAnnotationBeanPostProcessor() {
        return new RocketMQListenerKafkaProcessor();
    }
}
